=========================
Package Api Documentation
=========================


API Reference for classes in lyricsmaster.providers
---------------------------------------------------

.. automodule:: lyricsmaster.providers
    :member-order: bysource
    :members:
    :inherited-members:
    :show-inheritance:


API Reference for classes in lyricsmaster.models
------------------------------------------------

.. automodule:: lyricsmaster.models
    :member-order: bysource
    :members:


API Reference for classes in lyricsmaster.utils
-----------------------------------------------

.. autoclass:: lyricsmaster.utils.TorController
    :member-order: bysource
    :members:
    :inherited-members:


